<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it" sourcelanguage="en">
<context>
    <name>CenterlineVectorizer</name>
    <message>
        <source>Can&apos;t vectorize a %1 level</source>
        <translation type="vanished">Non è possibile vettorializzare un livello %1</translation>
    </message>
    <message>
        <source>Can&apos;t vectorize a level with no frames</source>
        <translation type="vanished">Non è possibile vettorializzare un livello senza fotogrammi</translation>
    </message>
    <message>
        <source>Can&apos;t vectorize a %1 image</source>
        <translation type="vanished">Non è possibile vettorializzare un&apos;immagine %1</translation>
    </message>
    <message>
        <source>Bad argument (%1): should be an Image or a Level</source>
        <translation type="vanished">Cattivo argomento (%1): deve essere un&apos; Immagine o un Livello</translation>
    </message>
</context>
<context>
    <name>FilePath</name>
    <message>
        <source>&quot;%1&quot;</source>
        <translation type="vanished">&quot;%1&quot;</translation>
    </message>
    <message>
        <source>can&apos;t concatenate an absolute path : %1</source>
        <translation type="vanished">non è possibile concatenare un path assoluto: %1</translation>
    </message>
    <message>
        <source>%1 is not a directory</source>
        <translation type="vanished">%1 non è una cartella</translation>
    </message>
    <message>
        <source>can&apos;t read directory %1</source>
        <translation type="vanished">Non è possibile leggere la cartella %1</translation>
    </message>
</context>
<context>
    <name>Image</name>
    <message>
        <source>File %1 doesn&apos;t exist</source>
        <translation type="vanished">Il file %1 non esiste</translation>
    </message>
    <message>
        <source>Loaded first frame of %1</source>
        <translation type="vanished">Caricato il priimo fotogramma di %1</translation>
    </message>
    <message>
        <source>Unexpected error while reading image</source>
        <translation type="vanished">Errore inaspettato durante la lettura dell&apos;immagine</translation>
    </message>
    <message>
        <source>Unrecognized file type :</source>
        <translation type="vanished">File di tipo sconosciuto:</translation>
    </message>
    <message>
        <source>Can&apos;t save a %1 image to this file type : %2</source>
        <translation type="vanished">Non è possibile salvare un&apos;immagine %1 in questo tipo di file: %2</translation>
    </message>
    <message>
        <source>Unexpected error while writing image</source>
        <translation type="vanished">Errore inaspettato durante òa scrittura dell&apos;immagine</translation>
    </message>
</context>
<context>
    <name>ImageBuilder</name>
    <message>
        <source>Bad argument (%1): should be &apos;Raster&apos; or ToonzRaster&apos;</source>
        <translation type="vanished">Argomento inappropriato (%1): deve essere &apos;Raster&apos; o &apos;Toonz Raster&apos;</translation>
    </message>
    <message>
        <source>ImageBuilder(%1 image)</source>
        <translation type="vanished">Costruttore immagine(%1 immagine)</translation>
    </message>
    <message>
        <source>%1 : %2</source>
        <translation type="vanished">%1 : %2</translation>
    </message>
    <message>
        <source>Bad argument (%1): should be a Transformation</source>
        <translation type="vanished">Argomento inappropriato (%1): deve essere una Trasformazione</translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>%1 frames</source>
        <translation type="vanished">fotogrammi %1</translation>
    </message>
    <message>
        <source>Bad argument (%1). It should be FilePath or string</source>
        <translation type="vanished">Argomento inappropriato (%1): Deve essere un FilePath o una stringa.</translation>
    </message>
    <message>
        <source>Exception loading level (%1)</source>
        <translation type="vanished">Eccezione nel caricamento del livello (%1)</translation>
    </message>
    <message>
        <source>File %1 doesn&apos;t exist</source>
        <translation type="vanished">Il file %1 non esiste</translation>
    </message>
    <message>
        <source>File %1 is unsupported</source>
        <translation type="vanished">Il file %1 non è supportato</translation>
    </message>
    <message>
        <source>Exception reading %1</source>
        <translation type="vanished">Eccezione leggendo %1</translation>
    </message>
    <message>
        <source>Can&apos;t save an empty level</source>
        <translation type="vanished">Non è possibile salvare un livello vuoto</translation>
    </message>
    <message>
        <source>Unrecognized file type :</source>
        <translation type="vanished">Tipo di file non riconosciuto</translation>
    </message>
    <message>
        <source>Can&apos;t save a %1 level to this file type : %2</source>
        <translation type="vanished">Non è possibile salvare un livello %1 in questo tipo di file: %2</translation>
    </message>
    <message>
        <source>Exception writing %1</source>
        <translation type="vanished">Eccezione scrivendo %1</translation>
    </message>
    <message>
        <source>frame index (%1) must be a number</source>
        <translation type="vanished">L&apos;indice del fotogramma (%1) deve essere un numero</translation>
    </message>
    <message>
        <source>frame index (%1) is out of range (0-%2)</source>
        <translation type="vanished">L&apos;indice del fotogramma (%1) non è compreso nell&apos;intervallo (0-%2)</translation>
    </message>
    <message>
        <source>second argument (%1) is not an image</source>
        <translation type="vanished">Il secondo argomento (%1) non è un&apos;immagine</translation>
    </message>
    <message>
        <source>can not insert a %1 image into a level</source>
        <translation type="vanished">Non posso inserire un&apos;immagine %1 nel livello</translation>
    </message>
    <message>
        <source>can not insert a %1 image to a %2 level</source>
        <translation type="vanished">Non posso inserire un&apos;immagine %1 in un livello %2</translation>
    </message>
</context>
<context>
    <name>OutlineVectorizer</name>
    <message>
        <source>Can&apos;t vectorize a %1 level</source>
        <translation type="vanished">Non è possibile vettorializzare un livello %1</translation>
    </message>
    <message>
        <source>Can&apos;t vectorize a level with no frames</source>
        <translation type="vanished">Non è possibile vettorializzare un livello senza fotogrammi</translation>
    </message>
    <message>
        <source>Can&apos;t vectorize a %1 image</source>
        <translation type="vanished">Non è possibile vettorializzare un&apos;immagine %1</translation>
    </message>
    <message>
        <source>Bad argument (%1): should be an Image or a Level</source>
        <translation type="vanished">Argomento inappropriato (%1): deve essere un&apos;Immagine o un Livello</translation>
    </message>
    <message>
        <source>Invalid color : </source>
        <translation type="vanished">Colore non valido:</translation>
    </message>
</context>
<context>
    <name>Preferences</name>
    <message>
        <source>Retas Level Format</source>
        <translation>Livello Formato raster</translation>
    </message>
    <message>
        <source>Adobe Photoshop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PNG</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>No restrictions for uncompressed avi video</source>
        <translation>Nessuna restrizione per i video AVI non compressi</translation>
    </message>
    <message>
        <source>video width must be a multiple of %1</source>
        <translation>la larghezza del video deve essere un multiplo di %1</translation>
    </message>
    <message>
        <source>video length must be a multiple of %1</source>
        <translation>l&apos;altezza del video deve essere un multiplo di %1</translation>
    </message>
    <message>
        <source>No restrictions for this codec</source>
        <translation>Nessuna restrizione per questo codec</translation>
    </message>
    <message>
        <source>Resolution restrictions:</source>
        <translation>Restrizioni di risoluzione:</translation>
    </message>
    <message>
        <source>It is not possible to communicate with the codec.
 Probably the codec cannot work correctly.</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>%1-%2</source>
        <translation>%1-%2</translation>
    </message>
    <message>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <source>Expected %1 argument(s) in %2, got %3</source>
        <translation>Argomento(i) atteso(i) %1 in %2, ottenuto %3</translation>
    </message>
    <message>
        <source>%1 is not a valid color (valid color names are &apos;red&apos;, &apos;transparent&apos;, &apos;#FF8800&apos;, ecc.)</source>
        <translation>%1 non è un colore valido (i nomi di colore validi sono &apos;red&apos;,  &apos;transparent&apos;, &apos;#FF8800&apos;, ecc.)</translation>
    </message>
    <message>
        <source>Vectorization failed</source>
        <translation>Vettorializzazione fallita</translation>
    </message>
    <message>
        <source>Argument doesn&apos;t look like a file path : %1</source>
        <translation>L&apos;argomento non sembra essere un file path: %1</translation>
    </message>
    <message>
        <source>Bad argument (%1): should be an Image (not empty)</source>
        <translation>Argomento inappropriato (%1): deve essere un&apos;immagine (non vuota)</translation>
    </message>
    <message>
        <source>Argument &apos;%1&apos; does not look like a FrameId</source>
        <translation>L&apos;argomento &apos;%1&apos; non sembra essere un FrameId</translation>
    </message>
    <message>
        <source>First argument must be a scene : %1</source>
        <translation>Il primo argomento deve essere una scena: %1</translation>
    </message>
    <message>
        <source>Can&apos;t render empty scene</source>
        <translation>Non è possibile renderizzare una scena vuota</translation>
    </message>
    <message>
        <source>The autocentering failed on the current drawing.</source>
        <translation></translation>
    </message>
    <message>
        <source>New Camera  %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New Pegbar  %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set Active Camera  %1 &gt; %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove Spline  %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New Motion Path  %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Link Motion Path  %1 &gt; %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove Object  %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove Column  </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Load into Current Palette  &gt; %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Replace with Current Palette  &gt; %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Studio Palette  : %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create Studio Palette  : %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Studio Palette Folder  : %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create Studio Palette Folder  : %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move Studio Palette Folder  : %1 : %2 &gt; %3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Arrange Styles  in Palette %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create Style#%1  in Palette %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Style  to Palette %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Page %1 to Palette %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Page %1 from Palette %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Load Color Model %1  to Palette %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename Page  %1 &gt; %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename Style#%1 in Palette%2  : %3 &gt; %4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Fx  : </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Insert Fx  : </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create Linked Fx  : %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Replace Fx  : </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unlink Fx  : %1 - - %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Make Macro Fx  : %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Explode Macro Fx  : %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create Output Fx</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connect to Xsheet  : </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disconnect from Xsheet  : </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Link</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Fx Node : %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paste Fx  :  </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disconnect Fx</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connect Fx : %1 - %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename Fx : %1 &gt; %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Group Fx</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ungroup Fx</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename Group  : %1 &gt; %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set Keyframe</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove Keyframe</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cycle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit Rotation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move X</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move Y</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move Z</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit Stack Order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit Scale W</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit Scale H</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit Scale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit PosPath</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit Shear X</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit Shear Y</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1  %2  Frame : %3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set Keyframe   %1 at frame %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove Keyframe   %1 at frame %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move Center   %1  Frame %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>color model</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set Picked Position of Style#%1 in Palette%2 : %3,%4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update Colors by Using Picked Positions in Palette %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Toggle Autopaint Option  Palette : %1  Style#%2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Green</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Blue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DarkYellow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DarkCyan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DarkMagenta</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can&apos;t save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Brightness</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Contrast</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>HRange</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Line Width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ColorThres</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>WhiteThres</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can&apos;t undo rename palette</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can&apos;t undo move palette</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can&apos;t redo rename palette</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can&apos;t redo move palette</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename Studio Palette : %1 &gt; %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Xsheet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Timeline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to save the following resources:
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to save palette.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>and %1 more item(s).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Orange</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yellow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Light Green</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Light Blue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dark Blue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Purple</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pink</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dark Pink</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>White</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Rasterizer</name>
    <message>
        <source>Expected a vector image: %1</source>
        <translation type="vanished">Attesa un&apos;immagine vettoriale: %1</translation>
    </message>
    <message>
        <source>Expected a vector level: %1</source>
        <translation type="vanished">Atteso un livello vettoriale: %1</translation>
    </message>
    <message>
        <source>Argument must be a vector level or image : </source>
        <translation type="vanished">L&apos;argomento deve essere un livello vettoriale o un&apos;immagine:</translation>
    </message>
    <message>
        <source>%1 has no palette</source>
        <translation type="vanished">%1 non ha palette</translation>
    </message>
</context>
<context>
    <name>Scene</name>
    <message>
        <source>File %1 doesn&apos;t exist</source>
        <translation type="vanished">Il File %1 non esiste</translation>
    </message>
    <message>
        <source>Exception reading %1</source>
        <translation type="vanished">Eccezione leggendo %1</translation>
    </message>
    <message>
        <source>Exception writing %1</source>
        <translation type="vanished">Eccezione scrivendo %1</translation>
    </message>
    <message>
        <source>Bad level type (%1): must be Vector,Raster or ToonzRaster</source>
        <translation type="vanished">Tipo di livello inappropriato (%1): deve essere Vector, raster o ToonzRaster</translation>
    </message>
    <message>
        <source>Can&apos;t add the level: name(%1) is already used</source>
        <translation type="vanished">Non è possibile aggiungere il livello: il nome (%1) è già usato</translation>
    </message>
    <message>
        <source>Can&apos;t load this kind of file as a level : %1</source>
        <translation type="vanished">Non è possibile caricare questo tipo di file come livello: %1</translation>
    </message>
    <message>
        <source>Could not load level %1</source>
        <translation type="vanished">Non è possibile caricare il livello %1</translation>
    </message>
    <message>
        <source>Level is not included in the scene : %1</source>
        <translation type="vanished">Il livello non è contenuto nella scena: %1</translation>
    </message>
    <message>
        <source>%1 : Expected a Level instance or a level name</source>
        <translation type="vanished">%1: attesa un&apos; istanza del livello o un nome di livello</translation>
    </message>
    <message>
        <source>Level &apos;%1&apos; is not included in the scene</source>
        <translation type="vanished">Il livello &apos;%1&apos; non è contenuto nella scena</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::CenterlineVectorizer</name>
    <message>
        <source>Can&apos;t vectorize a %1 level</source>
        <translation type="unfinished">Non è possibile vettorializzare un livello %1</translation>
    </message>
    <message>
        <source>Can&apos;t vectorize a level with no frames</source>
        <translation type="unfinished">Non è possibile vettorializzare un livello senza fotogrammi</translation>
    </message>
    <message>
        <source>Can&apos;t vectorize a %1 image</source>
        <translation type="unfinished">Non è possibile vettorializzare un&apos;immagine %1</translation>
    </message>
    <message>
        <source>Bad argument (%1): should be an Image or a Level</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TScriptBinding::FilePath</name>
    <message>
        <source>&quot;%1&quot;</source>
        <translation type="unfinished">&quot;%1&quot;</translation>
    </message>
    <message>
        <source>can&apos;t concatenate an absolute path : %1</source>
        <translation type="unfinished">non è possibile concatenare un path assoluto: %1</translation>
    </message>
    <message>
        <source>%1 is not a directory</source>
        <translation type="unfinished">%1 non è una cartella</translation>
    </message>
    <message>
        <source>can&apos;t read directory %1</source>
        <translation type="unfinished">Non è possibile leggere la cartella %1</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::Image</name>
    <message>
        <source>File %1 doesn&apos;t exist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Loaded first frame of %1</source>
        <translation type="unfinished">Caricato il priimo fotogramma di %1</translation>
    </message>
    <message>
        <source>Unexpected error while reading image</source>
        <translation type="unfinished">Errore inaspettato durante la lettura dell&apos;immagine</translation>
    </message>
    <message>
        <source>Unrecognized file type :</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can&apos;t save a %1 image to this file type : %2</source>
        <translation type="unfinished">Non è possibile salvare un&apos;immagine %1 in questo tipo di file: %2</translation>
    </message>
    <message>
        <source>Unexpected error while writing image</source>
        <translation type="unfinished">Errore inaspettato durante òa scrittura dell&apos;immagine</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::ImageBuilder</name>
    <message>
        <source>Bad argument (%1): should be &apos;Raster&apos; or ToonzRaster&apos;</source>
        <translation type="unfinished">Argomento inappropriato (%1): deve essere &apos;Raster&apos; o &apos;Toonz Raster&apos;</translation>
    </message>
    <message>
        <source>ImageBuilder(%1 image)</source>
        <translation type="unfinished">Costruttore immagine(%1 immagine)</translation>
    </message>
    <message>
        <source>%1 : %2</source>
        <translation type="unfinished">%1 : %2</translation>
    </message>
    <message>
        <source>Bad argument (%1): should be a Transformation</source>
        <translation type="unfinished">Argomento inappropriato (%1): deve essere una Trasformazione</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::Level</name>
    <message>
        <source>%1 frames</source>
        <translation type="unfinished">fotogrammi %1</translation>
    </message>
    <message>
        <source>Bad argument (%1). It should be FilePath or string</source>
        <translation type="unfinished">Argomento inappropriato (%1): Deve essere un FilePath o una stringa.</translation>
    </message>
    <message>
        <source>Exception loading level (%1)</source>
        <translation type="unfinished">Eccezione nel caricamento del livello (%1)</translation>
    </message>
    <message>
        <source>File %1 doesn&apos;t exist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File %1 is unsupported</source>
        <translation type="unfinished">Il file %1 non è supportato</translation>
    </message>
    <message>
        <source>Exception reading %1</source>
        <translation type="unfinished">Eccezione leggendo %1</translation>
    </message>
    <message>
        <source>Can&apos;t save an empty level</source>
        <translation type="unfinished">Non è possibile salvare un livello vuoto</translation>
    </message>
    <message>
        <source>Unrecognized file type :</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can&apos;t save a %1 level to this file type : %2</source>
        <translation type="unfinished">Non è possibile salvare un livello %1 in questo tipo di file: %2</translation>
    </message>
    <message>
        <source>Exception writing %1</source>
        <translation type="unfinished">Eccezione scrivendo %1</translation>
    </message>
    <message>
        <source>frame index (%1) must be a number</source>
        <translation type="unfinished">L&apos;indice del fotogramma (%1) deve essere un numero</translation>
    </message>
    <message>
        <source>frame index (%1) is out of range (0-%2)</source>
        <translation type="unfinished">L&apos;indice del fotogramma (%1) non è compreso nell&apos;intervallo (0-%2)</translation>
    </message>
    <message>
        <source>second argument (%1) is not an image</source>
        <translation type="unfinished">Il secondo argomento (%1) non è un&apos;immagine</translation>
    </message>
    <message>
        <source>can not insert a %1 image into a level</source>
        <translation type="unfinished">Non posso inserire un&apos;immagine %1 nel livello</translation>
    </message>
    <message>
        <source>can not insert a %1 image to a %2 level</source>
        <translation type="unfinished">Non posso inserire un&apos;immagine %1 in un livello %2</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::OutlineVectorizer</name>
    <message>
        <source>Can&apos;t vectorize a %1 level</source>
        <translation type="unfinished">Non è possibile vettorializzare un livello %1</translation>
    </message>
    <message>
        <source>Can&apos;t vectorize a level with no frames</source>
        <translation type="unfinished">Non è possibile vettorializzare un livello senza fotogrammi</translation>
    </message>
    <message>
        <source>Can&apos;t vectorize a %1 image</source>
        <translation type="unfinished">Non è possibile vettorializzare un&apos;immagine %1</translation>
    </message>
    <message>
        <source>Bad argument (%1): should be an Image or a Level</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid color : </source>
        <translation type="unfinished">Colore non valido:</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::Rasterizer</name>
    <message>
        <source>Expected a vector image: %1</source>
        <translation type="unfinished">Attesa un&apos;immagine vettoriale: %1</translation>
    </message>
    <message>
        <source>Expected a vector level: %1</source>
        <translation type="unfinished">Atteso un livello vettoriale: %1</translation>
    </message>
    <message>
        <source>Argument must be a vector level or image : </source>
        <translation type="unfinished">L&apos;argomento deve essere un livello vettoriale o un&apos;immagine:</translation>
    </message>
    <message>
        <source>%1 has no palette</source>
        <translation type="unfinished">%1 non ha palette</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::Scene</name>
    <message>
        <source>File %1 doesn&apos;t exist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exception reading %1</source>
        <translation type="unfinished">Eccezione leggendo %1</translation>
    </message>
    <message>
        <source>Exception writing %1</source>
        <translation type="unfinished">Eccezione scrivendo %1</translation>
    </message>
    <message>
        <source>Bad level type (%1): must be Vector,Raster or ToonzRaster</source>
        <translation type="unfinished">Tipo di livello inappropriato (%1): deve essere Vector, raster o ToonzRaster</translation>
    </message>
    <message>
        <source>Can&apos;t add the level: name(%1) is already used</source>
        <translation type="unfinished">Non è possibile aggiungere il livello: il nome (%1) è già usato</translation>
    </message>
    <message>
        <source>Can&apos;t load this kind of file as a level : %1</source>
        <translation type="unfinished">Non è possibile caricare questo tipo di file come livello: %1</translation>
    </message>
    <message>
        <source>Could not load level %1</source>
        <translation type="unfinished">Non è possibile caricare il livello %1</translation>
    </message>
    <message>
        <source>Level is not included in the scene : %1</source>
        <translation type="unfinished">Il livello non è contenuto nella scena: %1</translation>
    </message>
    <message>
        <source>%1 : Expected a Level instance or a level name</source>
        <translation type="unfinished">%1: attesa un&apos; istanza del livello o un nome di livello</translation>
    </message>
    <message>
        <source>Level &apos;%1&apos; is not included in the scene</source>
        <translation type="unfinished">Il livello &apos;%1&apos; non è contenuto nella scena</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::ToonzRasterConverter</name>
    <message>
        <source>Can&apos;t convert a %1 level</source>
        <translation type="unfinished">Non è possibile convertire un livello %1</translation>
    </message>
    <message>
        <source>Can&apos;t convert a level with no frames</source>
        <translation type="unfinished">Non è possibile convertire un livello senza fotogrammi</translation>
    </message>
    <message>
        <source>Can&apos;t convert a %1 image</source>
        <translation type="unfinished">Non è possibile convertire un&apos;immagine %1</translation>
    </message>
    <message>
        <source>Bad argument (%1): should be a raster Level or a raster Image</source>
        <translation type="unfinished">Argomento inappropriato (%1): deve essere un raster Level o una raster Image</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::Transform</name>
    <message>
        <source>Identity</source>
        <translation type="unfinished">Identità</translation>
    </message>
    <message>
        <source>Translation(%1,%2)</source>
        <translation type="unfinished">Traslazione(%1,%2)</translation>
    </message>
    <message>
        <source>Rotation(%1)</source>
        <translation type="unfinished">Rotazione(%1)</translation>
    </message>
    <message>
        <source>Scale(%1%)</source>
        <translation type="unfinished">Scale(%1%)</translation>
    </message>
    <message>
        <source>Scale(%1%, %2%)</source>
        <translation type="unfinished">Scala(%1%,%2%)</translation>
    </message>
    <message>
        <source>Transform(%1, %2, %3;  %4, %5, %6)</source>
        <translation type="unfinished">Impossibile vedere il file selezionato poichè il file non è stato ancora salvato.</translation>
    </message>
</context>
<context>
    <name>ToonzRasterConverter</name>
    <message>
        <source>Can&apos;t convert a %1 level</source>
        <translation type="vanished">Non è possibile convertire un livello %1</translation>
    </message>
    <message>
        <source>Can&apos;t convert a level with no frames</source>
        <translation type="vanished">Non è possibile convertire un livello senza fotogrammi</translation>
    </message>
    <message>
        <source>Can&apos;t convert a %1 image</source>
        <translation type="vanished">Non è possibile convertire un&apos;immagine %1</translation>
    </message>
    <message>
        <source>Bad argument (%1): should be a raster Level or a raster Image</source>
        <translation type="vanished">Argomento inappropriato (%1): deve essere un raster Level o una raster Image</translation>
    </message>
</context>
<context>
    <name>Transform</name>
    <message>
        <source>Identity</source>
        <translation type="vanished">Identità</translation>
    </message>
    <message>
        <source>Translation(%1,%2)</source>
        <translation type="vanished">Traslazione(%1,%2)</translation>
    </message>
    <message>
        <source>Rotation(%1)</source>
        <translation type="vanished">Rotazione(%1)</translation>
    </message>
    <message>
        <source>Scale(%1%)</source>
        <translation type="vanished">Scale(%1%)</translation>
    </message>
    <message>
        <source>Scale(%1%, %2%)</source>
        <translation type="vanished">Scala(%1%,%2%)</translation>
    </message>
    <message>
        <source>Transform(%1, %2, %3;  %4, %5, %6)</source>
        <translation type="vanished">Trasformazione(%1, %2, %3;  %4, %5, %6)</translation>
    </message>
</context>
</TS>
